@@ -15,11 +15,9 @@ use Scalar::Util;
 use constant VALIDATE_HOSTNAME => eval 'require Data::Validate::Domain;1';
 use constant VALIDATE_IP       => eval 'require Data::Validate::IP;1';
 
-use constant DEBUG => $ENV{JSON_VALIDATOR_DEBUG} || $ENV{SWAGGER2_DEBUG} || 0;
-use constant WARN_ON_MISSING_FORMAT => $ENV{JSON_VALIDATOR_WARN_ON_MISSING_FORMAT}
-  || $ENV{SWAGGER2_WARN_ON_MISSING_FORMAT} ? 1 : 0;
+use constant DEBUG => $ENV{JSON_VALIDATOR_DEBUG} || 0;
 
-our $VERSION = '0.71';
+our $VERSION = '0.72';
 our @EXPORT_OK = qw(validate_json);
 
 my $HTTP_SCHEME_RE = qr{^https?:};
@@ -33,7 +31,7 @@ sub validate_json {
 
 has cache_dir => sub {
   $ENV{JSON_VALIDATOR_CACHE_DIR}
-    || File::Spec->catdir(File::Basename::dirname(__FILE__), qw(JSON Validator));
+    || File::Spec->catdir(File::Basename::dirname(__FILE__), qw(Validator cache));
 };
 
 has formats => sub { shift->_build_formats };
@@ -149,17 +147,19 @@ sub _load_schema_from_data {
 sub _load_schema_from_text {
   return Mojo::JSON::decode_json($_[1]) if $_[1] =~ /^\s*\{/s;
   $_[0]->{coerce}{booleans} = 1;    # internal coercion
-  _load_yaml($_[1]);
+  _load_yaml($_[1]) || undef;
 }
 
 sub _load_schema_from_url {
   my ($self, $url, $namespace) = @_;
   my $cache_file = File::Spec->catfile($self->cache_dir, Mojo::Util::md5_sum($namespace));
 
+  warn "[JSON::Validator] Trying to load cached file $cache_file\n" if DEBUG;
   return Mojo::Util::slurp($cache_file) if -r $cache_file;
-  my $doc = $self->ua->get($url)->res->body;
-  Mojo::Util::spurt($doc, $cache_file) if $self->cache_dir and -w $self->cache_dir;
-  return $doc;
+  my $tx = $self->ua->get($url);
+  die $tx->error->{message} if $tx->error;
+  Mojo::Util::spurt($tx->res->body, $cache_file) if $self->cache_dir and -w $self->cache_dir;
+  return $tx->res->body;
 }
 
 sub _default_id {
@@ -366,13 +366,9 @@ sub _validate_type_enum {
 sub _validate_format {
   my ($self, $value, $path, $schema) = @_;
   my $code = $self->formats->{$schema->{format}};
-
-  unless ($code) {
-    warn "Format rule for '$schema->{format}' is missing" if WARN_ON_MISSING_FORMAT;
-    return;
-  }
-
-  return if $code->($value);
+  return if $code and $code->($value);
+  warn "Format rule for '$schema->{format}' is missing" unless $code;
+  return unless $code;
   return E $path, "Does not match $schema->{format} format.";
 }
 
@@ -730,7 +726,7 @@ JSON::Validator - Validate data against a JSON schema
 
 =head1 VERSION
 
-0.71
+0.72
 
 =head1 SYNOPSIS
 
@@ -764,10 +760,6 @@ You might want to use this instead of L<JSON::Schema> if you need to
 validate data against L<draft 4|https://github.com/json-schema/json-schema/tree/master/draft-04>
 of the specification.
 
-This module is currently EXPERIMENTAL. Hopefully nothing drastic will change,
-but it needs to fit together nicely with L<Swagger2> - Since this is a spin-off
-project.
-
 =head2 Supported schema formats
 
 L<JSON::Validator> can load JSON schemas in multiple formats: Plain perl data
